#ifndef SITEUI_H
#define SITEUI_H

#include "screem-application.h"
#include "screem-site.h"
#include "screem-window.h" 

gboolean screem_site_open_with_filename( ScreemWindow *window, 
					 ScreemApplication *application,
					 const gchar *filename );
void screem_site_druid( ScreemSite *site, ScreemWindow *window );
void screem_site_settings_dialog( ScreemSite *site, ScreemWindow *window );
void screem_site_close_site( ScreemSite *site );

void screem_site_create_template( ScreemWindow *window );

gboolean screem_site_save_confirmation( ScreemSite *site,
		ScreemWindow *window );

void screem_site_stats_dialog( ScreemSite *site, ScreemWindow *window );

#endif
